@@ -34,19 +34,26 @@
 bzr vcs support.
 """
 
+
 import os
 import sys
-import urllib
+# first try python3, then python2
+try:
+    from urllib.request import url2pathname
+except ImportError:
+    from urllib2 import url2pathname
 
-
-from vcs_base import VcsClientBase, VcsError, sanitized, normalized_rel_path, run_shell_command
+from vcstools.vcs_base import VcsClientBase, VcsError
+from vcstools.common import sanitized, normalized_rel_path, run_shell_command
 
 
 def _get_bzr_version():
     """Looks up bzr version by calling bzr --version.
     :raises: VcsError if bzr is not installed"""
     try:
-        value, output, _ = run_shell_command('bzr --version', shell=True, us_env = True)
+        value, output, _ = run_shell_command('bzr --version',
+                                             shell=True,
+                                             us_env=True)
         if value == 0 and output is not None and len(output.splitlines()) > 0:
             version = output.splitlines()[0]
         else:
@@ -63,7 +70,7 @@ class BzrClient(VcsClientBase):
         """
         VcsClientBase.__init__(self, 'bzr', path)
         _get_bzr_version()
-        
+
     @staticmethod
     def get_environment_metadata():
         metadict = {}
@@ -72,42 +79,72 @@ class BzrClient(VcsClientBase):
         except:
             metadict["version"] = "no bzr installed"
         return metadict
-        
+
     def get_url(self):
         """
         :returns: BZR URL of the branch (output of bzr info command), or None if it cannot be determined
         """
+        result = None
         if self.detect_presence():
             cmd = 'bzr info %s'%self._path
-            _, output, _ = run_shell_command(cmd, shell=True, us_env = True)
+            _, output, _ = run_shell_command(cmd, shell=True, us_env=True)
             matches = [l for l in output.splitlines() if l.startswith('  parent branch: ')]
             if matches:
-                ppath = urllib.url2pathname(matches[0][len('  parent branch: '):])
+                ppath = url2pathname(matches[0][len('  parent branch: '):])
                 # when it can, bzr substitues absolute path for relative paths
                 if (ppath is not None and os.path.isdir(ppath) and not os.path.isabs(ppath)):
-                    return os.path.abspath(os.path.join(os.getcwd(), ppath))
-                return ppath
-        return None
+                    result = os.path.abspath(os.path.join(os.getcwd(), ppath))
+                else:
+                    result = ppath
+        return result
+
+    def url_matches(self, url, url_or_shortcut):
+        if super(BzrClient, self).url_matches(url, url_or_shortcut):
+            return True
+        # if we got a shortcut (e.g. launchpad url), we compare using
+        # bzr info and return that one if result matches.
+        result = False
+        if url_or_shortcut is not None:
+            cmd = 'bzr info %s'%url_or_shortcut
+            value, output, _ = run_shell_command(cmd, shell=True, us_env=True)
+            if value == 0:
+                for line in output.splitlines():
+                    sline = line.strip()
+                    for prefix in ['shared repository: ',
+                                   'repository branch: ',
+                                   'branch root: ']:
+                        if sline.startswith(prefix):
+                            if super(BzrClient, self).url_matches(url, sline[len(prefix):]):
+                                result = True
+                                break
+        return result
 
     def detect_presence(self):
         return self.path_exists() and os.path.isdir(os.path.join(self._path, '.bzr'))
 
-    def checkout(self, url, version=None, verbose = False, shallow = False):
+    def checkout(self, url, version=None, verbose=False, shallow=False):
         cmd = 'bzr branch'
         if version:
             cmd += ' -r %s' % version
         cmd += ' %s %s' % (url, self._path)
-        value, _, _ = run_shell_command(cmd, shell=True, show_stdout = verbose, verbose = verbose)
+        value, _, _ = run_shell_command(cmd,
+                                        shell=True,
+                                        show_stdout=verbose,
+                                        verbose=verbose)
         if value != 0:
             if self.path_exists():
                 sys.stderr.write("Error: cannot checkout into existing directory\n")
             return False
         return True
 
-    def update(self, version='', verbose = False):
+    def update(self, version='', verbose=False):
         if not self.detect_presence():
             return False
-        value, _, _ = run_shell_command("bzr pull", cwd=self._path, shell=True, show_stdout = True, verbose = verbose)
+        value, _, _ = run_shell_command("bzr pull",
+                                        cwd=self._path,
+                                        shell=True,
+                                        show_stdout=True,
+                                        verbose=verbose)
         if value != 0:
             return False
         # Ignore verbose param, bzr is pretty verbose on update anyway
@@ -115,7 +152,11 @@ class BzrClient(VcsClientBase):
             cmd = "bzr update -r %s"%(version)
         else:
             cmd = "bzr update"
-        value, _, _ = run_shell_command(cmd, cwd=self._path, shell=True, show_stdout = True, verbose = verbose)
+        value, _, _ = run_shell_command(cmd,
+                                        cwd=self._path,
+                                        shell=True,
+                                        show_stdout=True,
+                                        verbose=verbose)
         if value == 0:
             return True
         return False
@@ -124,15 +165,18 @@ class BzrClient(VcsClientBase):
         """
         :param spec: (optional) revisionspec of desired version.  May
           be any revisionspec as returned by 'bzr help revisionspec',
-          e.g. a tagname or 'revno:<number>'        
+          e.g. a tagname or 'revno:<number>'
         :returns: the current revision number of the repository. Or if
           spec is provided, the number of a revision specified by some
-          token. 
+          token.
         """
         if self.detect_presence():
             if spec is not None:
                 command = ['bzr log -r %s .'%sanitized(spec)]
-                _, output, _ = run_shell_command(command, shell=True, cwd=self._path, us_env = True)
+                _, output, _ = run_shell_command(command,
+                                                 shell=True,
+                                                 cwd=self._path,
+                                                 us_env=True)
                 if output is None or output.strip() == '' or output.startswith("bzr:"):
                     return None
                 else:
@@ -140,12 +184,15 @@ class BzrClient(VcsClientBase):
                     if len(matches) == 1:
                         return matches[0].split()[1]
             else:
-                _, output, _ = run_shell_command('bzr revno --tree', shell=True, cwd=self._path, us_env = True)
+                _, output, _ = run_shell_command('bzr revno --tree',
+                                                 shell=True,
+                                                 cwd=self._path,
+                                                 us_env=True)
                 return output.strip()
 
     def get_diff(self, basepath=None):
         response = None
-        if basepath == None:
+        if basepath is None:
             basepath = self._path
         if self.path_exists():
             rel_path = sanitized(normalized_rel_path(self._path, basepath))
@@ -155,8 +202,8 @@ class BzrClient(VcsClientBase):
         return response
 
     def get_status(self, basepath=None, untracked=False):
-        response=None
-        if basepath == None:
+        response = None
+        if basepath is None:
             basepath = self._path
         if self.path_exists():
             rel_path = normalized_rel_path(self._path, basepath)
@@ -170,5 +217,5 @@ class BzrClient(VcsClientBase):
                     response_processed+=line[0:4]+rel_path+'/'+line[4:]+'\n'
             response = response_processed
         return response
-    
-BZRClient=BzrClient
+
+BZRClient = BzrClient
