@@ -30,15 +30,19 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+
 import os
 
-_vcs_types = {}
+_VCS_TYPES = {}
+
 
 def register_vcs(vcs_type, clazz):
-    _vcs_types[vcs_type] = clazz
-  
+    _VCS_TYPES[vcs_type] = clazz
+
+
 def get_vcs(vcs_type):
-    return _vcs_types[vcs_type]
+    return _VCS_TYPES[vcs_type]
+
 
 class VcsClient(object):
     """
@@ -50,9 +54,9 @@ class VcsClient(object):
         self._path = path
         clientclass = get_vcs(vcs_type)
         if clientclass is None:
-            raise LookupException("No Vcs client registered for type %s"%vcs_type)
+            raise LookupError("No Vcs client registered for type %s"%vcs_type)
         self.vcs = clientclass(path)
-    
+
     def path_exists(self):
         return os.path.exists(self._path)
 
@@ -63,11 +67,14 @@ class VcsClient(object):
     def get_version(self, spec=None):
         return self.vcs.get_version(spec)
 
-    def checkout(self, url, version='', verbose = False, shallow = False):
-        return self.vcs.checkout(url, version, verbose = verbose, shallow = shallow)
+    def checkout(self, url, version='', verbose=False, shallow=False):
+        return self.vcs.checkout(url, version, verbose=verbose, shallow=shallow)
 
-    def update(self, version, verbose = False):
-        return self.vcs.update(version, verbose = verbose)
+    def url_matches(self, url, url_or_shortcut):
+        return self.vcs.url_matches(url=url, url_or_shortcut=url_or_shortcut)
+
+    def update(self, version, verbose=False):
+        return self.vcs.update(version, verbose=verbose)
 
     def detect_presence(self):
         return self.vcs.detect_presence()
@@ -88,4 +95,4 @@ class VcsClient(object):
         return self.vcs.get_status(basepath, untracked)
 
 # backwards compat
-VCSClient=VcsClient
+VCSClient = VcsClient
