@@ -49,7 +49,7 @@ class BzrClientTestSetups(unittest.TestCase):
             subprocess.check_call(["bzr", "whoami"])
         except subprocess.CalledProcessError as e:
             subprocess.check_call(["bzr", "whoami", '"ros ros@ros.org"'])
-        
+
         directory = tempfile.mkdtemp()
         self.directories = dict(setUp=directory)
         self.remote_path = os.path.join(directory, "remote")
@@ -62,14 +62,14 @@ class BzrClientTestSetups(unittest.TestCase):
         subprocess.check_call(["bzr", "commit", "-m", "initial"], cwd=self.remote_path)
         subprocess.check_call(["bzr", "tag", "test_tag"], cwd=self.remote_path)
         self.local_version_init = "1"
-        
+
         # files to be modified in "local" repo
         subprocess.check_call(["touch", "modified.txt"], cwd=self.remote_path)
         subprocess.check_call(["touch", "modified-fs.txt"], cwd=self.remote_path)
         subprocess.check_call(["bzr", "add", "modified.txt", "modified-fs.txt"], cwd=self.remote_path)
         subprocess.check_call(["bzr", "commit", "-m", "initial"], cwd=self.remote_path)
         self.local_version_second = "2"
-        
+
         subprocess.check_call(["touch", "deleted.txt"], cwd=self.remote_path)
         subprocess.check_call(["touch", "deleted-fs.txt"], cwd=self.remote_path)
         subprocess.check_call(["bzr", "add", "deleted.txt", "deleted-fs.txt"], cwd=self.remote_path)
@@ -86,9 +86,48 @@ class BzrClientTestSetups(unittest.TestCase):
     def tearDown(self):
         if os.path.exists(self.local_path):
             shutil.rmtree(self.local_path)
-            
+
 class BzrClientTest(BzrClientTestSetups):
 
+    def test_url_matches_with_shortcut_strings(self):
+        client = BzrClient(self.local_path)
+        self.assertTrue(client.url_matches('test1234', 'test1234'))
+
+    def test_url_matches_with_shortcut_strings_slashes(self):
+        client = BzrClient(self.local_path)
+        self.assertTrue(client.url_matches('test1234/', 'test1234'))
+        self.assertTrue(client.url_matches('test1234', 'test1234/'))
+        self.assertTrue(client.url_matches('test1234/', 'test1234/'))
+
+    def get_launchpad_info(self, url):
+        po = subprocess.Popen(["bzr", "info", url], stdout=subprocess.PIPE)
+        output = po.stdout.read()
+        # it is not great to use the same code for testing as in
+        # production, but relying on fixed bzr info output is just as
+        # bad.
+        for line in output.splitlines():
+            sline = line.strip()
+            for prefix in ['shared repository: ',
+                           'repository branch: ',
+                           'branch root: ']:
+                if sline.startswith(prefix):
+                    return sline[len(prefix):]
+        return None
+
+    def test_url_matches_with_shortcut(self):
+        # bzr on launchpad should have shared repository
+        client = BzrClient(self.local_path)
+        url = 'lp:bzr'
+        url2 = self.get_launchpad_info(url)
+        self.assertFalse(url2 is None)
+        self.assertTrue(client.url_matches(url2, url), "%s~=%s"%(url, url2))
+
+        # launchpad on launchpad should be a branch root
+        url = 'lp:launchpad'
+        url2 = self.get_launchpad_info(url)
+        self.assertFalse(url2 is None)
+        self.assertTrue(client.url_matches(url2, url), "%s~=%s"%(url, url2))
+                                 
     def test_get_url_by_reading(self):
         client = BzrClient(self.local_path)
         url = self.remote_path
@@ -101,7 +140,7 @@ class BzrClientTest(BzrClientTestSetups):
         self.assertEqual(client.get_version(), self.local_version)
         self.assertEqual(client.get_version(self.local_version_init[0:6]), self.local_version_init)
         self.assertEqual(client.get_version("test_tag"), self.local_version_init)
-        
+
     def test_get_url_nonexistant(self):
         local_path = "/tmp/dummy"
         client = BzrClient(local_path)
@@ -152,7 +191,7 @@ class BzrClientTest(BzrClientTestSetups):
         self.assertEqual(client.get_path(), self.local_path)
         self.assertEqual(client.get_url(), url)
         self.assertEqual(client.get_version(), version)
-        
+
         new_version = '2'
         self.assertTrue(client.update(new_version))
         self.assertEqual(client.get_version(), new_version)
@@ -197,7 +236,7 @@ class BzrDiffStatClientTest(BzrClientTestSetups):
     @classmethod
     def tearDownClass(self):
         BzrClientTestSetups.tearDownClass()
-        
+
     def test_diff(self):
         client = BzrClient(self.local_path)
         self.assertTrue(client.path_exists())
@@ -220,16 +259,16 @@ class BzrDiffStatClientTest(BzrClientTestSetups):
         client = BzrClient(self.local_path)
         self.assertTrue(client.path_exists())
         self.assertTrue(client.detect_presence())
-        self.assertEquals('+N  ./added.txt\n D  ./deleted-fs.txt\n-D  ./deleted.txt\n M  ./modified-fs.txt\n M  ./modified.txt', client.get_status().rstrip())
+        self.assertEquals('+N  ./added.txt\n D  ./deleted-fs.txt\n-D  ./deleted.txt\n M  ./modified-fs.txt\n M  ./modified.txt\n', client.get_status())
 
     def test_status_relpath(self):
         client = BzrClient(self.local_path)
         self.assertTrue(client.path_exists())
         self.assertTrue(client.detect_presence())
-        self.assertEquals('+N  local/added.txt\n D  local/deleted-fs.txt\n-D  local/deleted.txt\n M  local/modified-fs.txt\n M  local/modified.txt', client.get_status(basepath=os.path.dirname(self.local_path)).rstrip())
+        self.assertEquals('+N  local/added.txt\n D  local/deleted-fs.txt\n-D  local/deleted.txt\n M  local/modified-fs.txt\n M  local/modified.txt\n', client.get_status(basepath=os.path.dirname(self.local_path)))
 
     def test_status_untracked(self):
         client = BzrClient(self.local_path)
         self.assertTrue(client.path_exists())
         self.assertTrue(client.detect_presence())
-        self.assertEquals('?   ./added-fs.txt\n+N  ./added.txt\n D  ./deleted-fs.txt\n-D  ./deleted.txt\n M  ./modified-fs.txt\n M  ./modified.txt', client.get_status(untracked=True).rstrip())
+        self.assertEquals('?   ./added-fs.txt\n+N  ./added.txt\n D  ./deleted-fs.txt\n-D  ./deleted.txt\n M  ./modified-fs.txt\n M  ./modified.txt\n', client.get_status(untracked=True))
